
package Paws::DS::CreateComputerResult;
  use Moose;
  has Computer => (is => 'ro', isa => 'Paws::DS::Computer');


### main pod documentation begin ###

=head1 NAME

Paws::DS::CreateComputerResult

=head1 ATTRIBUTES

=head2 Computer => Paws::DS::Computer

  

A Computer object the represents the computer account.











=cut

1;