
package Paws::OpsWorks::CreateDeploymentResult;
  use Moose;
  has DeploymentId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::CreateDeploymentResult

=head1 ATTRIBUTES

=head2 DeploymentId => Str

  

The deployment ID, which can be used with other requests to identify
the deployment.











=cut

1;