
package Paws::Route53Domains::UpdateTagsForDomainResponse;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::UpdateTagsForDomainResponse

=head1 ATTRIBUTES



=cut

1;