
package Paws::CodeDeploy::CreateApplicationOutput;
  use Moose;
  has applicationId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::CreateApplicationOutput

=head1 ATTRIBUTES

=head2 applicationId => Str

  

A unique application ID.











=cut

1;