
package Paws::KMS::GenerateRandom;
  use Moose;
  has NumberOfBytes => (is => 'ro', isa => 'Int');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GenerateRandom');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::KMS::GenerateRandomResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::KMS::GenerateRandom - Arguments for method GenerateRandom on Paws::KMS

=head1 DESCRIPTION

This class represents the parameters used for calling the method GenerateRandom on the 
AWS Key Management Service service. Use the attributes of this class
as arguments to method GenerateRandom.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GenerateRandom.

As an example:

  $service_obj->GenerateRandom(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 NumberOfBytes => Int

  

Integer that contains the number of bytes to generate. Common values
are 128, 256, 512, 1024 and so on. The current limit is 1024 bytes.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GenerateRandom in L<Paws::KMS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

