
package Paws::ImportExport::GetShippingLabelOutput;
  use Moose;
  has ShippingLabelURL => (is => 'ro', isa => 'Str');
  has Warning => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ImportExport::GetShippingLabelOutput

=head1 ATTRIBUTES

=head2 ShippingLabelURL => Str

  
=head2 Warning => Str

  


=cut

