
package Paws::ElasticTranscoder::DeletePipelineResponse;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticTranscoder::DeletePipelineResponse

=head1 ATTRIBUTES



=cut

