
package Paws::CloudWatchLogs::PutDestinationResponse;
  use Moose;
  has destination => (is => 'ro', isa => 'Paws::CloudWatchLogs::Destination');


### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::PutDestinationResponse

=head1 ATTRIBUTES

=head2 destination => Paws::CloudWatchLogs::Destination

  


=cut

1;