
package Paws::RedShift::CreateClusterSubnetGroupResult;
  use Moose;
  has ClusterSubnetGroup => (is => 'ro', isa => 'Paws::RedShift::ClusterSubnetGroup');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::CreateClusterSubnetGroupResult

=head1 ATTRIBUTES

=head2 ClusterSubnetGroup => Paws::RedShift::ClusterSubnetGroup

  


=cut

