
package Paws::ElasticTranscoder::ReadJobResponse;
  use Moose;
  has Job => (is => 'ro', isa => 'Paws::ElasticTranscoder::Job');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticTranscoder::ReadJobResponse

=head1 ATTRIBUTES

=head2 Job => Paws::ElasticTranscoder::Job

  

A section of the response body that provides information about the job.











=cut

