
package Paws::DataPipeline::EvaluateExpressionOutput;
  use Moose;
  has evaluatedExpression => (is => 'ro', isa => 'Str', required => 1);


### main pod documentation begin ###

=head1 NAME

Paws::DataPipeline::EvaluateExpressionOutput

=head1 ATTRIBUTES

=head2 B<REQUIRED> evaluatedExpression => Str

  

The evaluated expression.











=cut

1;