
package Paws::STS::GetSessionTokenResponse;
  use Moose;
  has Credentials => (is => 'ro', isa => 'Paws::STS::Credentials');

1;

### main pod documentation begin ###

=head1 NAME

Paws::STS::GetSessionTokenResponse

=head1 ATTRIBUTES

=head2 Credentials => Paws::STS::Credentials

  

The session credentials for API authentication.











=cut

