
package Paws::Support::DescribeAttachmentResponse;
  use Moose;
  has attachment => (is => 'ro', isa => 'Paws::Support::Attachment');


### main pod documentation begin ###

=head1 NAME

Paws::Support::DescribeAttachmentResponse

=head1 ATTRIBUTES

=head2 attachment => Paws::Support::Attachment

  

The attachment content and file name.











=cut

1;