
package Paws::RedShift::CreateHsmClientCertificateResult;
  use Moose;
  has HsmClientCertificate => (is => 'ro', isa => 'Paws::RedShift::HsmClientCertificate');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::CreateHsmClientCertificateResult

=head1 ATTRIBUTES

=head2 HsmClientCertificate => Paws::RedShift::HsmClientCertificate

  


=cut

