package Paws::DeviceFarm::Artifact;
  use Moose;
  has arn => (is => 'ro', isa => 'Str');
  has extension => (is => 'ro', isa => 'Str');
  has name => (is => 'ro', isa => 'Str');
  has type => (is => 'ro', isa => 'Str');
  has url => (is => 'ro', isa => 'Str');
1;
