
package Paws::CodeDeploy::GetApplicationOutput;
  use Moose;
  has application => (is => 'ro', isa => 'Paws::CodeDeploy::ApplicationInfo');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetApplicationOutput

=head1 ATTRIBUTES

=head2 application => Paws::CodeDeploy::ApplicationInfo

  

Information about the application.











=cut

1;