
package Paws::CodeDeploy::GetDeploymentConfigOutput;
  use Moose;
  has deploymentConfigInfo => (is => 'ro', isa => 'Paws::CodeDeploy::DeploymentConfigInfo');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetDeploymentConfigOutput

=head1 ATTRIBUTES

=head2 deploymentConfigInfo => Paws::CodeDeploy::DeploymentConfigInfo

  

Information about the deployment configuration.











=cut

1;