
package Paws::DS::DeleteSnapshotResult;
  use Moose;
  has SnapshotId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::DS::DeleteSnapshotResult

=head1 ATTRIBUTES

=head2 SnapshotId => Str

  

The identifier of the directory snapshot that was deleted.











=cut

1;