
package Paws::DynamoDB::CreateTableOutput;
  use Moose;
  has TableDescription => (is => 'ro', isa => 'Paws::DynamoDB::TableDescription');


### main pod documentation begin ###

=head1 NAME

Paws::DynamoDB::CreateTableOutput

=head1 ATTRIBUTES

=head2 TableDescription => Paws::DynamoDB::TableDescription

  


=cut

1;