
package Paws::Support::AddCommunicationToCaseResponse;
  use Moose;
  has result => (is => 'ro', isa => 'Bool');


### main pod documentation begin ###

=head1 NAME

Paws::Support::AddCommunicationToCaseResponse

=head1 ATTRIBUTES

=head2 result => Bool

  

True if AddCommunicationToCase succeeds. Otherwise, returns an error.











=cut

1;