
package Paws::Support::DescribeTrustedAdvisorCheckResultResponse;
  use Moose;
  has result => (is => 'ro', isa => 'Paws::Support::TrustedAdvisorCheckResult');


### main pod documentation begin ###

=head1 NAME

Paws::Support::DescribeTrustedAdvisorCheckResultResponse

=head1 ATTRIBUTES

=head2 result => Paws::Support::TrustedAdvisorCheckResult

  

The detailed results of the Trusted Advisor check.











=cut

1;