
package Paws::ElasticBeanstalk::ConfigurationSettingsDescriptions;
  use Moose;
  has ConfigurationSettings => (is => 'ro', isa => 'ArrayRef[Paws::ElasticBeanstalk::ConfigurationSettingsDescription]');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::ConfigurationSettingsDescriptions

=head1 ATTRIBUTES

=head2 ConfigurationSettings => ArrayRef[Paws::ElasticBeanstalk::ConfigurationSettingsDescription]

  

A list of ConfigurationSettingsDescription.











=cut

