
package Paws::RedShift::RotateEncryptionKeyResult;
  use Moose;
  has Cluster => (is => 'ro', isa => 'Paws::RedShift::Cluster');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::RotateEncryptionKeyResult

=head1 ATTRIBUTES

=head2 Cluster => Paws::RedShift::Cluster

  


=cut

