
package Paws::DeviceFarm::CreateUploadResult;
  use Moose;
  has upload => (is => 'ro', isa => 'Paws::DeviceFarm::Upload');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::CreateUploadResult

=head1 ATTRIBUTES

=head2 upload => Paws::DeviceFarm::Upload

  

The newly created upload.











=cut

1;