
package Paws::AutoScaling::DetachLoadBalancersResultType;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::DetachLoadBalancersResultType

=head1 ATTRIBUTES



=cut

