
package Paws::Inspector::UpdateAssessmentResponse;
  use Moose;
  has message => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::UpdateAssessmentResponse

=head1 ATTRIBUTES

=head2 message => Str

  

Confirmation details of the action performed.











=cut

1;