
package Paws::OpsWorks::CreateLayerResult;
  use Moose;
  has LayerId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::CreateLayerResult

=head1 ATTRIBUTES

=head2 LayerId => Str

  

The layer ID.











=cut

1;