
package Paws::DeviceFarm::GetAccountSettingsResult;
  use Moose;
  has accountSettings => (is => 'ro', isa => 'Paws::DeviceFarm::AccountSettings');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetAccountSettingsResult

=head1 ATTRIBUTES

=head2 accountSettings => Paws::DeviceFarm::AccountSettings

  


=cut

1;