
package Paws::ECS::DeleteServiceResponse;
  use Moose;
  has service => (is => 'ro', isa => 'Paws::ECS::Service');


### main pod documentation begin ###

=head1 NAME

Paws::ECS::DeleteServiceResponse

=head1 ATTRIBUTES

=head2 service => Paws::ECS::Service

  

The full description of the deleted service.











=cut

1;