
package Paws::RDS::CreateDBSubnetGroupResult;
  use Moose;
  has DBSubnetGroup => (is => 'ro', isa => 'Paws::RDS::DBSubnetGroup');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::CreateDBSubnetGroupResult

=head1 ATTRIBUTES

=head2 DBSubnetGroup => Paws::RDS::DBSubnetGroup

  


=cut

