
package Paws::ECS::StopTaskResponse;
  use Moose;
  has task => (is => 'ro', isa => 'Paws::ECS::Task');


### main pod documentation begin ###

=head1 NAME

Paws::ECS::StopTaskResponse

=head1 ATTRIBUTES

=head2 task => Paws::ECS::Task

  


=cut

1;