
package Paws::RDS::PurchaseReservedDBInstancesOfferingResult;
  use Moose;
  has ReservedDBInstance => (is => 'ro', isa => 'Paws::RDS::ReservedDBInstance');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::PurchaseReservedDBInstancesOfferingResult

=head1 ATTRIBUTES

=head2 ReservedDBInstance => Paws::RDS::ReservedDBInstance

  


=cut

