
package Paws::Inspector::CreateApplication;
  use Moose;
  has applicationName => (is => 'ro', isa => 'Str');
  has resourceGroupArn => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateApplication');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Inspector::CreateApplicationResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Inspector::CreateApplication - Arguments for method CreateApplication on Paws::Inspector

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateApplication on the 
Amazon Inspector service. Use the attributes of this class
as arguments to method CreateApplication.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CreateApplication.

As an example:

  $service_obj->CreateApplication(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 applicationName => Str

  

The user-defined name identifying the application that you want to
create. The name must be unique within the AWS account.










=head2 resourceGroupArn => Str

  

The ARN specifying the resource group that is used to create the
application.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateApplication in L<Paws::Inspector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

