
package Paws::ElasticBeanstalk::EnvironmentResourceDescriptionsMessage;
  use Moose;
  has EnvironmentResources => (is => 'ro', isa => 'Paws::ElasticBeanstalk::EnvironmentResourceDescription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::EnvironmentResourceDescriptionsMessage

=head1 ATTRIBUTES

=head2 EnvironmentResources => Paws::ElasticBeanstalk::EnvironmentResourceDescription

  

A list of EnvironmentResourceDescription.











=cut

