
package Paws::OpsWorks::DescribeMyUserProfileResult;
  use Moose;
  has UserProfile => (is => 'ro', isa => 'Paws::OpsWorks::SelfUserProfile');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::DescribeMyUserProfileResult

=head1 ATTRIBUTES

=head2 UserProfile => Paws::OpsWorks::SelfUserProfile

  

A C<UserProfile> object that describes the user's SSH information.











=cut

1;