
package Paws::RDS::DBParameterGroupNameMessage;
  use Moose;
  has DBParameterGroupName => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DBParameterGroupNameMessage

=head1 ATTRIBUTES

=head2 DBParameterGroupName => Str

  

Provides the name of the DB parameter group.











=cut

