
package Paws::ElastiCache::CreateCacheParameterGroupResult;
  use Moose;
  has CacheParameterGroup => (is => 'ro', isa => 'Paws::ElastiCache::CacheParameterGroup');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::CreateCacheParameterGroupResult

=head1 ATTRIBUTES

=head2 CacheParameterGroup => Paws::ElastiCache::CacheParameterGroup

  


=cut

