
package Paws::CodePipeline::GetPipelineOutput;
  use Moose;
  has pipeline => (is => 'ro', isa => 'Paws::CodePipeline::PipelineDeclaration');


### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::GetPipelineOutput

=head1 ATTRIBUTES

=head2 pipeline => Paws::CodePipeline::PipelineDeclaration

  


=cut

1;