
package Paws::CognitoSync::DescribeIdentityPoolUsageResponse;
  use Moose;
  has IdentityPoolUsage => (is => 'ro', isa => 'Paws::CognitoSync::IdentityPoolUsage');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoSync::DescribeIdentityPoolUsageResponse

=head1 ATTRIBUTES

=head2 IdentityPoolUsage => Paws::CognitoSync::IdentityPoolUsage

  

Information about the usage of the identity pool.











=cut

