
package Paws::DS::ConnectDirectoryResult;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::DS::ConnectDirectoryResult

=head1 ATTRIBUTES

=head2 DirectoryId => Str

  

The identifier of the new directory.











=cut

1;