
package Paws::CodeDeploy::CreateDeploymentOutput;
  use Moose;
  has deploymentId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::CreateDeploymentOutput

=head1 ATTRIBUTES

=head2 deploymentId => Str

  

A unique deployment ID.











=cut

1;