
package Paws::CodeCommit::CreateRepositoryOutput;
  use Moose;
  has repositoryMetadata => (is => 'ro', isa => 'Paws::CodeCommit::RepositoryMetadata');


### main pod documentation begin ###

=head1 NAME

Paws::CodeCommit::CreateRepositoryOutput

=head1 ATTRIBUTES

=head2 repositoryMetadata => Paws::CodeCommit::RepositoryMetadata

  

Information about the newly created repository.











=cut

1;