
package Paws::DeviceFarm::GetDevicePoolResult;
  use Moose;
  has devicePool => (is => 'ro', isa => 'Paws::DeviceFarm::DevicePool');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetDevicePoolResult

=head1 ATTRIBUTES

=head2 devicePool => Paws::DeviceFarm::DevicePool

  


=cut

1;