
package Paws::DeviceFarm::CreateProjectResult;
  use Moose;
  has project => (is => 'ro', isa => 'Paws::DeviceFarm::Project');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::CreateProjectResult

=head1 ATTRIBUTES

=head2 project => Paws::DeviceFarm::Project

  

The newly created project.











=cut

1;