
package Paws::RedShift::PurchaseReservedNodeOfferingResult;
  use Moose;
  has ReservedNode => (is => 'ro', isa => 'Paws::RedShift::ReservedNode');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::PurchaseReservedNodeOfferingResult

=head1 ATTRIBUTES

=head2 ReservedNode => Paws::RedShift::ReservedNode

  


=cut

