
package Paws::IoT::GetTopicRuleResponse;
  use Moose;
  has rule => (is => 'ro', isa => 'Paws::IoT::TopicRule');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::GetTopicRuleResponse

=head1 ATTRIBUTES

=head2 rule => Paws::IoT::TopicRule

  

The rule.











=cut

