
package Paws::RDS::RestoreDBClusterToPointInTimeResult;
  use Moose;
  has DBCluster => (is => 'ro', isa => 'Paws::RDS::DBCluster');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::RestoreDBClusterToPointInTimeResult

=head1 ATTRIBUTES

=head2 DBCluster => Paws::RDS::DBCluster

  


=cut

