
package Paws::SSM::CreateAssociationResult;
  use Moose;
  has AssociationDescription => (is => 'ro', isa => 'Paws::SSM::AssociationDescription');


### main pod documentation begin ###

=head1 NAME

Paws::SSM::CreateAssociationResult

=head1 ATTRIBUTES

=head2 AssociationDescription => Paws::SSM::AssociationDescription

  

Information about the association.











=cut

1;