
package Paws::CloudWatchLogs::CreateExportTaskResponse;
  use Moose;
  has taskId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::CreateExportTaskResponse

=head1 ATTRIBUTES

=head2 taskId => Str

  

Id of the export task that got created.











=cut

1;