
package Paws::Inspector::CreateApplicationResponse;
  use Moose;
  has applicationArn => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::CreateApplicationResponse

=head1 ATTRIBUTES

=head2 applicationArn => Str

  

The ARN specifying the application that is created.











=cut

1;