
package Paws::SSM::CreateDocumentResult;
  use Moose;
  has DocumentDescription => (is => 'ro', isa => 'Paws::SSM::DocumentDescription');


### main pod documentation begin ###

=head1 NAME

Paws::SSM::CreateDocumentResult

=head1 ATTRIBUTES

=head2 DocumentDescription => Paws::SSM::DocumentDescription

  

Information about the configuration document.











=cut

1;