
package Paws::Inspector::DescribeAssessmentResponse;
  use Moose;
  has assessment => (is => 'ro', isa => 'Paws::Inspector::Assessment');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeAssessmentResponse

=head1 ATTRIBUTES

=head2 assessment => Paws::Inspector::Assessment

  

Information about the assessment.











=cut

1;