
package Paws::EMR::DescribeStepOutput;
  use Moose;
  has Step => (is => 'ro', isa => 'Paws::EMR::Step');


### main pod documentation begin ###

=head1 NAME

Paws::EMR::DescribeStepOutput

=head1 ATTRIBUTES

=head2 Step => Paws::EMR::Step

  

The step details for the requested step identifier.











=cut

1;