
package Paws::StorageGateway::AddTagsToResourceOutput;
  use Moose;
  has ResourceARN => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::AddTagsToResourceOutput

=head1 ATTRIBUTES

=head2 ResourceARN => Str

  

The Amazon Resource Name (ARN) of the resource you want to add tags to.











=cut

1;