
package Paws::CodeCommit::GetBranchOutput;
  use Moose;
  has branch => (is => 'ro', isa => 'Paws::CodeCommit::BranchInfo');


### main pod documentation begin ###

=head1 NAME

Paws::CodeCommit::GetBranchOutput

=head1 ATTRIBUTES

=head2 branch => Paws::CodeCommit::BranchInfo

  

The name of the branch.











=cut

1;