
package Paws::CodePipeline::CreateCustomActionTypeOutput;
  use Moose;
  has actionType => (is => 'ro', isa => 'Paws::CodePipeline::ActionType', required => 1);


### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::CreateCustomActionTypeOutput

=head1 ATTRIBUTES

=head2 B<REQUIRED> actionType => Paws::CodePipeline::ActionType

  


=cut

1;