
package Paws::DeviceFarm::GetTestResult;
  use Moose;
  has test => (is => 'ro', isa => 'Paws::DeviceFarm::Test');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetTestResult

=head1 ATTRIBUTES

=head2 test => Paws::DeviceFarm::Test

  


=cut

1;