
package Paws::SQS::GetQueueUrlResult;
  use Moose;
  has QueueUrl => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::SQS::GetQueueUrlResult

=head1 ATTRIBUTES

=head2 QueueUrl => Str

  

The URL for the queue.











=cut

