
package Paws::DeviceFarm::GetSuiteResult;
  use Moose;
  has suite => (is => 'ro', isa => 'Paws::DeviceFarm::Suite');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetSuiteResult

=head1 ATTRIBUTES

=head2 suite => Paws::DeviceFarm::Suite

  


=cut

1;