
package Paws::OpsWorks::RegisterEcsClusterResult;
  use Moose;
  has EcsClusterArn => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::RegisterEcsClusterResult

=head1 ATTRIBUTES

=head2 EcsClusterArn => Str

  

The cluster's ARN.











=cut

1;