
package Paws::ECS::UpdateContainerAgentResponse;
  use Moose;
  has containerInstance => (is => 'ro', isa => 'Paws::ECS::ContainerInstance');


### main pod documentation begin ###

=head1 NAME

Paws::ECS::UpdateContainerAgentResponse

=head1 ATTRIBUTES

=head2 containerInstance => Paws::ECS::ContainerInstance

  


=cut

1;