
package Paws::CodeDeploy::GetDeploymentInstanceOutput;
  use Moose;
  has instanceSummary => (is => 'ro', isa => 'Paws::CodeDeploy::InstanceSummary');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetDeploymentInstanceOutput

=head1 ATTRIBUTES

=head2 instanceSummary => Paws::CodeDeploy::InstanceSummary

  

Information about the instance.











=cut

1;