
package Paws::OpsWorks::RegisterVolumeResult;
  use Moose;
  has VolumeId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::RegisterVolumeResult

=head1 ATTRIBUTES

=head2 VolumeId => Str

  

The volume ID.











=cut

1;