
package Paws::AutoScaling::ActivityType;
  use Moose;
  has Activity => (is => 'ro', isa => 'Paws::AutoScaling::Activity');

1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::ActivityType

=head1 ATTRIBUTES

=head2 Activity => Paws::AutoScaling::Activity

  

A scaling activity.











=cut

