
package Paws::ElastiCache::ModifyCacheClusterResult;
  use Moose;
  has CacheCluster => (is => 'ro', isa => 'Paws::ElastiCache::CacheCluster');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::ModifyCacheClusterResult

=head1 ATTRIBUTES

=head2 CacheCluster => Paws::ElastiCache::CacheCluster

  


=cut

