
package Paws::OpsWorks::DescribeStackSummaryResult;
  use Moose;
  has StackSummary => (is => 'ro', isa => 'Paws::OpsWorks::StackSummary');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::DescribeStackSummaryResult

=head1 ATTRIBUTES

=head2 StackSummary => Paws::OpsWorks::StackSummary

  

A C<StackSummary> object that contains the results.











=cut

1;