
package Paws::IoT::DescribeCertificateResponse;
  use Moose;
  has certificateDescription => (is => 'ro', isa => 'Paws::IoT::CertificateDescription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::DescribeCertificateResponse

=head1 ATTRIBUTES

=head2 certificateDescription => Paws::IoT::CertificateDescription

  

The description of the certificate.











=cut

