
package Paws::Inspector::DescribeResourceGroupResponse;
  use Moose;
  has resourceGroup => (is => 'ro', isa => 'Paws::Inspector::ResourceGroup');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeResourceGroupResponse

=head1 ATTRIBUTES

=head2 resourceGroup => Paws::Inspector::ResourceGroup

  

Information about the resource group.











=cut

1;