
package Paws::ElasticBeanstalk::ApplicationDescriptionMessage;
  use Moose;
  has Application => (is => 'ro', isa => 'Paws::ElasticBeanstalk::ApplicationDescription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::ApplicationDescriptionMessage

=head1 ATTRIBUTES

=head2 Application => Paws::ElasticBeanstalk::ApplicationDescription

  

The ApplicationDescription of the application.











=cut

