package Paws::ECS::ContainerDefinition;
  use Moose;
  has command => (is => 'ro', isa => 'ArrayRef[Str]');
  has cpu => (is => 'ro', isa => 'Int');
  has disableNetworking => (is => 'ro', isa => 'Bool');
  has dnsSearchDomains => (is => 'ro', isa => 'ArrayRef[Str]');
  has dnsServers => (is => 'ro', isa => 'ArrayRef[Str]');
  has dockerLabels => (is => 'ro', isa => 'Paws::ECS::DockerLabelsMap');
  has dockerSecurityOptions => (is => 'ro', isa => 'ArrayRef[Str]');
  has entryPoint => (is => 'ro', isa => 'ArrayRef[Str]');
  has environment => (is => 'ro', isa => 'ArrayRef[Paws::ECS::KeyValuePair]');
  has essential => (is => 'ro', isa => 'Bool');
  has extraHosts => (is => 'ro', isa => 'ArrayRef[Paws::ECS::HostEntry]');
  has hostname => (is => 'ro', isa => 'Str');
  has image => (is => 'ro', isa => 'Str');
  has links => (is => 'ro', isa => 'ArrayRef[Str]');
  has logConfiguration => (is => 'ro', isa => 'Paws::ECS::LogConfiguration');
  has memory => (is => 'ro', isa => 'Int');
  has mountPoints => (is => 'ro', isa => 'ArrayRef[Paws::ECS::MountPoint]');
  has name => (is => 'ro', isa => 'Str');
  has portMappings => (is => 'ro', isa => 'ArrayRef[Paws::ECS::PortMapping]');
  has privileged => (is => 'ro', isa => 'Bool');
  has readonlyRootFilesystem => (is => 'ro', isa => 'Bool');
  has ulimits => (is => 'ro', isa => 'ArrayRef[Paws::ECS::Ulimit]');
  has user => (is => 'ro', isa => 'Str');
  has volumesFrom => (is => 'ro', isa => 'ArrayRef[Paws::ECS::VolumeFrom]');
  has workingDirectory => (is => 'ro', isa => 'Str');
1;
