
package Paws::CognitoSync::DescribeIdentityUsageResponse;
  use Moose;
  has IdentityUsage => (is => 'ro', isa => 'Paws::CognitoSync::IdentityUsage');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoSync::DescribeIdentityUsageResponse

=head1 ATTRIBUTES

=head2 IdentityUsage => Paws::CognitoSync::IdentityUsage

  

Usage information for the identity.











=cut

