
package Paws::CodeDeploy::GetDeploymentOutput;
  use Moose;
  has deploymentInfo => (is => 'ro', isa => 'Paws::CodeDeploy::DeploymentInfo');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetDeploymentOutput

=head1 ATTRIBUTES

=head2 deploymentInfo => Paws::CodeDeploy::DeploymentInfo

  

Information about the deployment.











=cut

1;