
package Paws::ELB::SetLoadBalancerPoliciesForBackendServerOutput;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::ELB::SetLoadBalancerPoliciesForBackendServerOutput

=head1 ATTRIBUTES



=cut

