
package Paws::DS::GetDirectoryLimitsResult;
  use Moose;
  has DirectoryLimits => (is => 'ro', isa => 'Paws::DS::DirectoryLimits');


### main pod documentation begin ###

=head1 NAME

Paws::DS::GetDirectoryLimitsResult

=head1 ATTRIBUTES

=head2 DirectoryLimits => Paws::DS::DirectoryLimits

  

A DirectoryLimits object that contains the directory limits for the
current region.











=cut

1;