
package Paws::RDS::CreateDBClusterSnapshotResult;
  use Moose;
  has DBClusterSnapshot => (is => 'ro', isa => 'Paws::RDS::DBClusterSnapshot');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::CreateDBClusterSnapshotResult

=head1 ATTRIBUTES

=head2 DBClusterSnapshot => Paws::RDS::DBClusterSnapshot

  


=cut

