
package Paws::RDS::DeleteEventSubscriptionResult;
  use Moose;
  has EventSubscription => (is => 'ro', isa => 'Paws::RDS::EventSubscription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DeleteEventSubscriptionResult

=head1 ATTRIBUTES

=head2 EventSubscription => Paws::RDS::EventSubscription

  


=cut

