
package Paws::Config::DeliverConfigSnapshotResponse;
  use Moose;
  has configSnapshotId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Config::DeliverConfigSnapshotResponse

=head1 ATTRIBUTES

=head2 configSnapshotId => Str

  

The ID of the snapshot that is being created.











=cut

1;