
package Paws::Inspector::DescribeApplicationResponse;
  use Moose;
  has application => (is => 'ro', isa => 'Paws::Inspector::Application');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeApplicationResponse

=head1 ATTRIBUTES

=head2 application => Paws::Inspector::Application

  

Information about the application.











=cut

1;