
package Paws::CodePipeline::StartPipelineExecutionOutput;
  use Moose;
  has pipelineExecutionId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::StartPipelineExecutionOutput

=head1 ATTRIBUTES

=head2 pipelineExecutionId => Str

  

The unique system-generated ID of the pipeline that was started.











=cut

1;