
package Paws::Firehose::CreateDeliveryStreamOutput;
  use Moose;
  has DeliveryStreamARN => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Firehose::CreateDeliveryStreamOutput

=head1 ATTRIBUTES

=head2 DeliveryStreamARN => Str

  

The ARN of the delivery stream.











=cut

1;