
package Paws::RedShift::CopyClusterSnapshotResult;
  use Moose;
  has Snapshot => (is => 'ro', isa => 'Paws::RedShift::Snapshot');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::CopyClusterSnapshotResult

=head1 ATTRIBUTES

=head2 Snapshot => Paws::RedShift::Snapshot

  


=cut

