
package Paws::IoT::ListThingPrincipalsResponse;
  use Moose;
  has principals => (is => 'ro', isa => 'ArrayRef[Str]');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::ListThingPrincipalsResponse

=head1 ATTRIBUTES

=head2 principals => ArrayRef[Str]

  

The principals.











=cut

