
package Paws::DirectConnect::Interconnects;
  use Moose;
  has interconnects => (is => 'ro', isa => 'ArrayRef[Paws::DirectConnect::Interconnect]');


### main pod documentation begin ###

=head1 NAME

Paws::DirectConnect::Interconnects

=head1 ATTRIBUTES

=head2 interconnects => ArrayRef[Paws::DirectConnect::Interconnect]

  

A list of interconnects.











=cut

1;