
package Paws::CloudFormation::EstimateTemplateCostOutput;
  use Moose;
  has Url => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFormation::EstimateTemplateCostOutput

=head1 ATTRIBUTES

=head2 Url => Str

  

An AWS Simple Monthly Calculator URL with a query string that describes
the resources required to run the template.











=cut

