
package Paws::CognitoSync::UnsubscribeFromDatasetResponse;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoSync::UnsubscribeFromDatasetResponse

=head1 ATTRIBUTES



=cut

