
package Paws::Inspector::CreateResourceGroupResponse;
  use Moose;
  has resourceGroupArn => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::CreateResourceGroupResponse

=head1 ATTRIBUTES

=head2 resourceGroupArn => Str

  

The ARN specifying the resource group that is created.











=cut

1;