
package Paws::CloudSearch::BuildSuggestersResponse;
  use Moose;
  has FieldNames => (is => 'ro', isa => 'ArrayRef[Str]');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudSearch::BuildSuggestersResponse

=head1 ATTRIBUTES

=head2 FieldNames => ArrayRef[Str]

  


=cut

