
package Paws::ElasticBeanstalk::ApplicationVersionDescriptionMessage;
  use Moose;
  has ApplicationVersion => (is => 'ro', isa => 'Paws::ElasticBeanstalk::ApplicationVersionDescription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::ApplicationVersionDescriptionMessage

=head1 ATTRIBUTES

=head2 ApplicationVersion => Paws::ElasticBeanstalk::ApplicationVersionDescription

  

The ApplicationVersionDescription of the application version.











=cut

