
package Paws::DeviceFarm::GetDeviceResult;
  use Moose;
  has device => (is => 'ro', isa => 'Paws::DeviceFarm::Device');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetDeviceResult

=head1 ATTRIBUTES

=head2 device => Paws::DeviceFarm::Device

  


=cut

1;