
package Paws::Inspector::DescribeRulesPackageResponse;
  use Moose;
  has rulesPackage => (is => 'ro', isa => 'Paws::Inspector::RulesPackage');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeRulesPackageResponse

=head1 ATTRIBUTES

=head2 rulesPackage => Paws::Inspector::RulesPackage

  

Information about the rules package.











=cut

1;