
package Paws::StorageGateway::DescribeStorediSCSIVolumesOutput;
  use Moose;
  has StorediSCSIVolumes => (is => 'ro', isa => 'ArrayRef[Paws::StorageGateway::StorediSCSIVolume]');


### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::DescribeStorediSCSIVolumesOutput

=head1 ATTRIBUTES

=head2 StorediSCSIVolumes => ArrayRef[Paws::StorageGateway::StorediSCSIVolume]

  


=cut

1;