
package Paws::KMS::GetKeyPolicyResponse;
  use Moose;
  has Policy => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::KMS::GetKeyPolicyResponse

=head1 ATTRIBUTES

=head2 Policy => Str

  

A policy document in JSON format.











=cut

1;