
package Paws::OpsWorks::CreateInstanceResult;
  use Moose;
  has InstanceId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::CreateInstanceResult

=head1 ATTRIBUTES

=head2 InstanceId => Str

  

The instance ID.











=cut

1;