
package Paws::EMR::DescribeClusterOutput;
  use Moose;
  has Cluster => (is => 'ro', isa => 'Paws::EMR::Cluster');


### main pod documentation begin ###

=head1 NAME

Paws::EMR::DescribeClusterOutput

=head1 ATTRIBUTES

=head2 Cluster => Paws::EMR::Cluster

  

This output contains the details for the requested cluster.











=cut

1;