package Paws::IoT::CertificateDescription;
  use Moose;
  has certificateArn => (is => 'ro', isa => 'Str');
  has certificateId => (is => 'ro', isa => 'Str');
  has certificatePem => (is => 'ro', isa => 'Str');
  has creationDate => (is => 'ro', isa => 'Str');
  has lastModifiedDate => (is => 'ro', isa => 'Str');
  has ownedBy => (is => 'ro', isa => 'Str');
  has status => (is => 'ro', isa => 'Str');
1;
