
package Paws::RDS::DeleteDBSnapshotResult;
  use Moose;
  has DBSnapshot => (is => 'ro', isa => 'Paws::RDS::DBSnapshot');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DeleteDBSnapshotResult

=head1 ATTRIBUTES

=head2 DBSnapshot => Paws::RDS::DBSnapshot

  


=cut

