
package Paws::RedShift::CreateSnapshotCopyGrantResult;
  use Moose;
  has SnapshotCopyGrant => (is => 'ro', isa => 'Paws::RedShift::SnapshotCopyGrant');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::CreateSnapshotCopyGrantResult

=head1 ATTRIBUTES

=head2 SnapshotCopyGrant => Paws::RedShift::SnapshotCopyGrant

  


=cut

