
package Paws::CodeCommit::DeleteRepositoryOutput;
  use Moose;
  has repositoryId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CodeCommit::DeleteRepositoryOutput

=head1 ATTRIBUTES

=head2 repositoryId => Str

  

The ID of the repository that was deleted.











=cut

1;