
package Paws::ElastiCache::CacheParameterGroupNameMessage;
  use Moose;
  has CacheParameterGroupName => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::CacheParameterGroupNameMessage

=head1 ATTRIBUTES

=head2 CacheParameterGroupName => Str

  

The name of the cache parameter group.











=cut

