
package Paws::IoT::DescribeEndpointResponse;
  use Moose;
  has endpointAddress => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::DescribeEndpointResponse

=head1 ATTRIBUTES

=head2 endpointAddress => Str

  

The address.











=cut

