
package Paws::ElastiCache::PurchaseReservedCacheNodesOfferingResult;
  use Moose;
  has ReservedCacheNode => (is => 'ro', isa => 'Paws::ElastiCache::ReservedCacheNode');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::PurchaseReservedCacheNodesOfferingResult

=head1 ATTRIBUTES

=head2 ReservedCacheNode => Paws::ElastiCache::ReservedCacheNode

  


=cut

