
package Paws::CloudWatchLogs::TestMetricFilterResponse;
  use Moose;
  has matches => (is => 'ro', isa => 'ArrayRef[Paws::CloudWatchLogs::MetricFilterMatchRecord]');


### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::TestMetricFilterResponse

=head1 ATTRIBUTES

=head2 matches => ArrayRef[Paws::CloudWatchLogs::MetricFilterMatchRecord]

  


=cut

1;