
package Paws::IoTData::UpdateThingShadowResponse;
  use Moose;
  has payload => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTData::UpdateThingShadowResponse

=head1 ATTRIBUTES

=head2 payload => Str

  

The state information, in JSON format.











=cut

