
package Paws::Inspector::DescribeRunResponse;
  use Moose;
  has run => (is => 'ro', isa => 'Paws::Inspector::Run');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeRunResponse

=head1 ATTRIBUTES

=head2 run => Paws::Inspector::Run

  

Information about the assessment run.











=cut

1;