
package Paws::SNS::CreatePlatformApplicationResponse;
  use Moose;
  has PlatformApplicationArn => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::SNS::CreatePlatformApplicationResponse

=head1 ATTRIBUTES

=head2 PlatformApplicationArn => Str

  

PlatformApplicationArn is returned.











=cut

