
package Paws::KMS::GetKeyRotationStatusResponse;
  use Moose;
  has KeyRotationEnabled => (is => 'ro', isa => 'Bool');


### main pod documentation begin ###

=head1 NAME

Paws::KMS::GetKeyRotationStatusResponse

=head1 ATTRIBUTES

=head2 KeyRotationEnabled => Bool

  

A Boolean value that specifies whether key rotation is enabled.











=cut

1;