
package Paws::IAM::CreatePolicyVersionResponse;
  use Moose;
  has PolicyVersion => (is => 'ro', isa => 'Paws::IAM::PolicyVersion');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::CreatePolicyVersionResponse

=head1 ATTRIBUTES

=head2 PolicyVersion => Paws::IAM::PolicyVersion

  

Information about the policy version.











=cut

