
package Paws::Inspector::DescribeFindingResponse;
  use Moose;
  has finding => (is => 'ro', isa => 'Paws::Inspector::Finding');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeFindingResponse

=head1 ATTRIBUTES

=head2 finding => Paws::Inspector::Finding

  

Information about the finding.











=cut

1;