
package Paws::Inspector::RunAssessmentResponse;
  use Moose;
  has runArn => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::Inspector::RunAssessmentResponse

=head1 ATTRIBUTES

=head2 runArn => Str

  

The ARN specifying the run of the assessment.











=cut

1;