
package Paws::RedShift::CreateHsmConfigurationResult;
  use Moose;
  has HsmConfiguration => (is => 'ro', isa => 'Paws::RedShift::HsmConfiguration');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::CreateHsmConfigurationResult

=head1 ATTRIBUTES

=head2 HsmConfiguration => Paws::RedShift::HsmConfiguration

  


=cut

