
package Paws::ECS::CreateClusterResponse;
  use Moose;
  has cluster => (is => 'ro', isa => 'Paws::ECS::Cluster');


### main pod documentation begin ###

=head1 NAME

Paws::ECS::CreateClusterResponse

=head1 ATTRIBUTES

=head2 cluster => Paws::ECS::Cluster

  

The full description of your new cluster.











=cut

1;