
package Paws::SES::SendBounceResponse;
  use Moose;
  has MessageId => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::SES::SendBounceResponse

=head1 ATTRIBUTES

=head2 MessageId => Str

  

The message ID of the bounce message.











=cut

