
package Paws::CodeDeploy::GetDeploymentGroupOutput;
  use Moose;
  has deploymentGroupInfo => (is => 'ro', isa => 'Paws::CodeDeploy::DeploymentGroupInfo');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetDeploymentGroupOutput

=head1 ATTRIBUTES

=head2 deploymentGroupInfo => Paws::CodeDeploy::DeploymentGroupInfo

  

Information about the deployment group.











=cut

1;