
package Paws::SES::SetIdentityFeedbackForwardingEnabledResponse;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::SES::SetIdentityFeedbackForwardingEnabledResponse

=head1 ATTRIBUTES



=cut

