
package Paws::CloudHSM::CreateLunaClientResponse;
  use Moose;
  has ClientArn => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CloudHSM::CreateLunaClientResponse

=head1 ATTRIBUTES

=head2 ClientArn => Str

  

The ARN of the client.











=cut

1;