
package Paws::RDS::CreateDBClusterParameterGroupResult;
  use Moose;
  has DBClusterParameterGroup => (is => 'ro', isa => 'Paws::RDS::DBClusterParameterGroup');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::CreateDBClusterParameterGroupResult

=head1 ATTRIBUTES

=head2 DBClusterParameterGroup => Paws::RDS::DBClusterParameterGroup

  


=cut

