
package Paws::StorageGateway::UpdateSnapshotScheduleOutput;
  use Moose;
  has VolumeARN => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::UpdateSnapshotScheduleOutput

=head1 ATTRIBUTES

=head2 VolumeARN => Str

  


=cut

1;