
package Paws::Route53Domains::EnableDomainAutoRenewResponse;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::EnableDomainAutoRenewResponse

=head1 ATTRIBUTES



=cut

1;