
package Paws::DS::CreateSnapshotResult;
  use Moose;
  has SnapshotId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::DS::CreateSnapshotResult

=head1 ATTRIBUTES

=head2 SnapshotId => Str

  

The identifier of the snapshot that was created.











=cut

1;