
package Paws::RDS::ApplyPendingMaintenanceActionResult;
  use Moose;
  has ResourcePendingMaintenanceActions => (is => 'ro', isa => 'Paws::RDS::ResourcePendingMaintenanceActions');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::ApplyPendingMaintenanceActionResult

=head1 ATTRIBUTES

=head2 ResourcePendingMaintenanceActions => Paws::RDS::ResourcePendingMaintenanceActions

  


=cut

