
package Paws::Route53Domains::DeleteTagsForDomainResponse;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::DeleteTagsForDomainResponse

=head1 ATTRIBUTES



=cut

1;