
package Paws::IAM::CreateUserResponse;
  use Moose;
  has User => (is => 'ro', isa => 'Paws::IAM::User');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::CreateUserResponse

=head1 ATTRIBUTES

=head2 User => Paws::IAM::User

  

Information about the user.











=cut

