
package Paws::DS::CreateDirectoryResult;
  use Moose;
  has DirectoryId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::DS::CreateDirectoryResult

=head1 ATTRIBUTES

=head2 DirectoryId => Str

  

The identifier of the directory that was created.











=cut

1;