
package Paws::CodeDeploy::CreateDeploymentConfigOutput;
  use Moose;
  has deploymentConfigId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::CreateDeploymentConfigOutput

=head1 ATTRIBUTES

=head2 deploymentConfigId => Str

  

A unique deployment configuration ID.











=cut

1;