
package Paws::MarketplaceCommerceAnalytics::GenerateDataSetResult;
  use Moose;
  has dataSetRequestId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::MarketplaceCommerceAnalytics::GenerateDataSetResult

=head1 ATTRIBUTES

=head2 dataSetRequestId => Str

  


=cut

1;