
package Paws::RedShift::ModifyEventSubscriptionResult;
  use Moose;
  has EventSubscription => (is => 'ro', isa => 'Paws::RedShift::EventSubscription');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::ModifyEventSubscriptionResult

=head1 ATTRIBUTES

=head2 EventSubscription => Paws::RedShift::EventSubscription

  


=cut

