
package Paws::ECS::SubmitContainerStateChangeResponse;
  use Moose;
  has acknowledgment => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::ECS::SubmitContainerStateChangeResponse

=head1 ATTRIBUTES

=head2 acknowledgment => Str

  

Acknowledgement of the state change.











=cut

1;