
package Paws::Glacier::GetDataRetrievalPolicyOutput;
  use Moose;
  has Policy => (is => 'ro', isa => 'Paws::Glacier::DataRetrievalPolicy');

1;

### main pod documentation begin ###

=head1 NAME

Paws::Glacier::GetDataRetrievalPolicyOutput

=head1 ATTRIBUTES

=head2 Policy => Paws::Glacier::DataRetrievalPolicy

  

Contains the returned data retrieval policy in JSON format.











=cut

