
package Paws::StorageGateway::DisableGatewayOutput;
  use Moose;
  has GatewayARN => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::StorageGateway::DisableGatewayOutput

=head1 ATTRIBUTES

=head2 GatewayARN => Str

  

The unique Amazon Resource Name of the disabled gateway.











=cut

1;