
package Paws::RedShift::DescribeDefaultClusterParametersResult;
  use Moose;
  has DefaultClusterParameters => (is => 'ro', isa => 'Paws::RedShift::DefaultClusterParameters');

1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DescribeDefaultClusterParametersResult

=head1 ATTRIBUTES

=head2 DefaultClusterParameters => Paws::RedShift::DefaultClusterParameters

  


=cut

