
package Paws::EMR::RunJobFlowOutput;
  use Moose;
  has JobFlowId => (is => 'ro', isa => 'Str');


### main pod documentation begin ###

=head1 NAME

Paws::EMR::RunJobFlowOutput

=head1 ATTRIBUTES

=head2 JobFlowId => Str

  

An unique identifier for the job flow.











=cut

1;