
package Paws::ElastiCache::RevokeCacheSecurityGroupIngressResult;
  use Moose;
  has CacheSecurityGroup => (is => 'ro', isa => 'Paws::ElastiCache::CacheSecurityGroup');

1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::RevokeCacheSecurityGroupIngressResult

=head1 ATTRIBUTES

=head2 CacheSecurityGroup => Paws::ElastiCache::CacheSecurityGroup

  


=cut

