
package Paws::Route53Domains::DisableDomainAutoRenewResponse;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::Route53Domains::DisableDomainAutoRenewResponse

=head1 ATTRIBUTES



=cut

1;