
package Paws::DeviceFarm::GetJobResult;
  use Moose;
  has job => (is => 'ro', isa => 'Paws::DeviceFarm::Job');


### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetJobResult

=head1 ATTRIBUTES

=head2 job => Paws::DeviceFarm::Job

  


=cut

1;