
package Paws::CloudSearch::CreateDomainResponse;
  use Moose;
  has DomainStatus => (is => 'ro', isa => 'Paws::CloudSearch::DomainStatus');

1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudSearch::CreateDomainResponse

=head1 ATTRIBUTES

=head2 DomainStatus => Paws::CloudSearch::DomainStatus

  


=cut

